"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class SdGenerationStyle(str, Enum):
    r"""The style to generate images with. When photoReal is enabled, use CINEMATIC, CREATIVE, VIBRANT, or NONE. When alchemy is disabled, use LEONARDO or NONE. When alchemy is enabled, use ANIME, CREATIVE, DYNAMIC, ENVIRONMENT, GENERAL, ILLUSTRATION, PHOTOGRAPHY, RAYTRACED, RENDER_3D, SKETCH_BW, SKETCH_COLOR, or NONE."""
    ANIME = 'ANIME'
    CINEMATIC = 'CINEMATIC'
    CREATIVE = 'CREATIVE'
    DYNAMIC = 'DYNAMIC'
    ENVIRONMENT = 'ENVIRONMENT'
    GENERAL = 'GENERAL'
    ILLUSTRATION = 'ILLUSTRATION'
    LEONARDO = 'LEONARDO'
    NONE = 'NONE'
    PHOTOGRAPHY = 'PHOTOGRAPHY'
    RAYTRACED = 'RAYTRACED'
    RENDER_3_D = 'RENDER_3D'
    SKETCH_BW = 'SKETCH_BW'
    SKETCH_COLOR = 'SKETCH_COLOR'
    VIBRANT = 'VIBRANT'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from dataclasses_json import Undefined, dataclass_json
from leonardoaisdk import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UploadDatasetImageFromGenRequestBody:
    r"""Query parameters to be provided in the request body as a JSON object"""
    generated_image_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('generatedImageId') }})
    r"""The ID of the image to upload to the dataset."""
    



@dataclasses.dataclass
class UploadDatasetImageFromGenRequest:
    dataset_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'datasetId', 'style': 'simple', 'explode': False }})
    r"""The ID of the dataset to upload the image to."""
    request_body: UploadDatasetImageFromGenRequestBody = dataclasses.field(metadata={'request': { 'media_type': 'application/json' }})
    r"""Query parameters to be provided in the request body as a JSON object"""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class DatasetGenUploadOutput:
    id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UploadDatasetImageFromGenResponseBody:
    r"""Responses for POST /datasets/{datasetId}/upload/gen"""
    upload_dataset_image_from_gen: Optional[DatasetGenUploadOutput] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uploadDatasetImageFromGen') }})
    



@dataclasses.dataclass
class UploadDatasetImageFromGenResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    raw_response: requests_http.Response = dataclasses.field()
    r"""Raw HTTP response; suitable for custom response parsing"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    object: Optional[UploadDatasetImageFromGenResponseBody] = dataclasses.field(default=None)
    r"""Responses for POST /datasets/{datasetId}/upload/gen"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class Strength(str, Enum):
    r"""When training using the PIXEL_ART model type, this influences the training strength."""
    VERY_LOW = 'VERY_LOW'
    LOW = 'LOW'
    MEDIUM = 'MEDIUM'
    HIGH = 'HIGH'



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .sdkconfiguration import SDKConfiguration
from leonardoaisdk import utils
from leonardoaisdk.models import errors, operations
from typing import Optional

class User:
    sdk_configuration: SDKConfiguration

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        self.sdk_configuration = sdk_config
        
    
    
    def get_user_self(self) -> operations.GetUserSelfResponse:
        r"""Get user information
        This endpoint will return your user information such as your user id, username, token renewal date and current amounts of the following: subscription tokens, gpt (prompt generation) tokens, and model training tokens
        """
        base_url = utils.template_url(*self.sdk_configuration.get_server_details())
        
        url = base_url + '/me'
        headers = {}
        headers['Accept'] = 'application/json'
        headers['user-agent'] = self.sdk_configuration.user_agent
        
        if callable(self.sdk_configuration.security):
            client = utils.configure_security_client(self.sdk_configuration.client, self.sdk_configuration.security())
        else:
            client = utils.configure_security_client(self.sdk_configuration.client, self.sdk_configuration.security)
        
        http_res = client.request('GET', url, headers=headers)
        content_type = http_res.headers.get('Content-Type')
        
        res = operations.GetUserSelfResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserSelfResponseBody])
                res.object = out
            else:
                raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
        elif http_res.status_code >= 400 and http_res.status_code < 500 or http_res.status_code >= 500 and http_res.status_code < 600:
            raise errors.SDKError('API error occurred', http_res.status_code, http_res.text, http_res)

        return res

    